@@ -1,6 +1,6 @@
 import logging
 
-from notecoin.database.base import create_all, session
+from notecoin.database.base import create_all, create_session
 from notecoin.okex.database.websocket import OkexSocketPublicTickers
 from notecoin.okex.websocket.utils import get_local_timestamp
 
@@ -8,6 +8,7 @@ from notecoin.okex.websocket.utils import get_local_timestamp
 class BaseHandle:
     def __init__(self, channels, *args, **kwargs):
         self.channels = channels
+        self.session = create_session()
 
     def solve(self, data) -> bool:
         data = eval(data)
@@ -32,8 +33,8 @@ class PublicTickers(BaseHandle):
     def handle(self, data) -> bool:
         try:
             for arg in data['data']:
-                session.merge(OkexSocketPublicTickers(**arg))
-                session.commit()
+                self.session.merge(OkexSocketPublicTickers(**arg))
+                self.session.commit()
         except Exception as e:
             logging.error(f"error:{e}")
             return False
@@ -51,9 +52,10 @@ class ResponseHandel(BaseHandle):
                 "channel": data['arg']['channel'],
                 "response": str(data)
             }
-            session.merge(OkexSocketPublicTickers(**res))
-            session.commit()
+            self.session.merge(OkexSocketPublicTickers(**res))
+            self.session.commit()
         except Exception as e:
+            self.session.rollback()
             logging.error(f"error:{e}")
             return False
         return True
